@@ -1,9 +1,9 @@
 /* BLURB gpl
 
                            Coda File System
-                              Release 6
+                              Release 8
 
-          Copyright (c) 1987-2003 Carnegie Mellon University
+          Copyright (c) 1987-2025 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -16,14 +16,6 @@ listed in the file CREDITS.
 
 #*/
 
-
-
-
-
-
-
-
-
 /*
  *
  *    Specification of recoverable binary search tree.
@@ -43,22 +35,19 @@ extern "C" {
 }
 #endif
 
-
 #include "bstree.h"
 #include "rvmlib.h"
 
-
 class rec_bstree;
 class rec_bsnode;
 class rec_bstree_iterator;
 typedef int (*RBSTCFN)(rec_bsnode *, rec_bsnode *);
 
-
 /*enum BstGetType { BstGetMin, BstGetMax };*/
 
 class rec_bstree {
     rec_bsnode *root;
-    RBSTCFN CmpFn;					/* function to order the nodes */
+    RBSTCFN CmpFn; /* function to order the nodes */
     int cnt;
 
     /* statistics */
@@ -66,48 +55,49 @@ class rec_bstree {
     int removes;
     int gets;
 
-  public:
-    void *operator new (size_t);
-    void operator delete(void *);
+public:
+    void *operator new(size_t) REQUIRES_TRANSACTION;
+    void operator delete(void *) REQUIRES_TRANSACTION;
 
     rec_bstree(RBSTCFN);
-    rec_bstree(rec_bstree&);				/* not supported! */
+    rec_bstree(rec_bstree &); /* not supported! */
     ~rec_bstree();
-    void Init(RBSTCFN);
+    void Init(RBSTCFN) REQUIRES_TRANSACTION;
     void SetCmpFn(RBSTCFN);
-    void ClearStatistics();
-    int operator=(rec_bstree&);				/* not supported! */
+    void ClearStatistics() REQUIRES_TRANSACTION;
+    int operator=(rec_bstree &); /* not supported! */
     void DeInit();
 
-    void insert(rec_bsnode *);				/* insert in sorted order */
-    rec_bsnode *remove(rec_bsnode *);			/* remove specified entry */
-    rec_bsnode *first();				/* return MINIMUM node */
-    rec_bsnode *last();					/* return MAXMIMUM node */
-    rec_bsnode *get(BstGetType =BstGetMin);		/* return and remove MIN or MAX node */
+    void insert(rec_bsnode *) REQUIRES_TRANSACTION; /* insert in sorted order */
+    rec_bsnode *
+    remove(rec_bsnode *) REQUIRES_TRANSACTION; /* remove specified entry */
+    rec_bsnode *first(); /* return MINIMUM node */
+    rec_bsnode *last(); /* return MAXMIMUM node */
+    rec_bsnode *get(BstGetType = BstGetMin)
+        REQUIRES_TRANSACTION; /* return and remove MIN or MAX node */
 
     int count();
     int IsMember(rec_bsnode *);
-    int	IsOrdered();					/* sanity checker */
+    int IsOrdered(); /* sanity checker */
     /*virtual*/ void print();
     /*virtual*/ void print(FILE *);
     /*virtual*/ void print(int);
 };
 
-
 class rec_bsnode {
-  friend class rec_bstree;
-  friend class rec_bstree_iterator;
+    friend class rec_bstree;
+    friend class rec_bstree_iterator;
     rec_bstree *mytree;
     rec_bsnode *parent;
     rec_bsnode *leftchild;
     rec_bsnode *rightchild;
 
-  public:
+public:
     rec_bsnode();
-    void Init();
-    rec_bsnode(rec_bsnode&);				/* not supported! */
-    int operator=(rec_bsnode&);				/* not supported! */
-/*
+    void Init() REQUIRES_TRANSACTION;
+    rec_bsnode(rec_bsnode &); /* not supported! */
+    int operator=(rec_bsnode &); /* not supported! */
+    /*
     ~rec_bsnode();
     void DeInit();
 */
@@ -118,17 +108,16 @@ class rec_bsnode {
     /*virtual*/ void print(int);
 };
 
-
 /*enum BstIterOrder { BstAscending, BstDescending };*/
 
 class rec_bstree_iterator {
-    rec_bstree *crec_bstree;				/* tree being iterated over */
-    rec_bsnode *crec_bsnode;				/* current node in the iteration */
+    rec_bstree *crec_bstree; /* tree being iterated over */
+    rec_bsnode *crec_bsnode; /* current node in the iteration */
     BstIterOrder order;
 
-  public:
-    rec_bstree_iterator(rec_bstree&, BstIterOrder =BstAscending);
-    rec_bsnode *operator()();				/* return next node or 0 */
+public:
+    rec_bstree_iterator(rec_bstree &, BstIterOrder = BstAscending);
+    rec_bsnode *operator()(); /* return next node or 0 */
 };
 
 #endif /* _UTIL_REC_BSTREE_H_ */
