@@ -1,9 +1,9 @@
 /* BLURB gpl
 
                            Coda File System
-                              Release 6
+                              Release 8
 
-          Copyright (c) 1987-2008 Carnegie Mellon University
+          Copyright (c) 1987-2021 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -18,7 +18,7 @@ listed in the file CREDITS.
 
 extern void CLIENT_InitHostTable(void);
 extern int CLIENT_Build(RPC2_Handle, char *, RPC2_Integer, SecretToken *,
-			ClientEntry **);
+                        ClientEntry **);
 extern void CLIENT_Delete(ClientEntry *);
 extern void CLIENT_CleanUpHost(HostTable *);
 extern void CLIENT_GetWorkStats(int *, int *, unsigned int);
@@ -28,15 +28,15 @@ int CLIENT_MakeCallBackConn(ClientEntry *Client);
 
 char *ViceErrorMsg(int errorCode);
 
-extern void Die (char *);
+extern void Die(char *);
 extern int GetEtherStats();
 extern int InitCallBack();
-extern void ViceLog (int ...);
+extern void ViceLog(int...);
 extern void DeleteCallBack(HostTable *, ViceFid *);
 extern void BreakCallBack(HostTable *, ViceFid *);
-extern void DeleteVenus (HostTable *);
-extern void DeleteFile (ViceFid *);
-extern int InitCallBack ();
+extern void DeleteVenus(HostTable *);
+extern void DeleteFile(ViceFid *);
+extern int InitCallBack();
 
 extern int check_reintegration_retry;
-
+struct timeval *srv_rpc2_timeout();
