@@ -1,9 +1,9 @@
 /* BLURB gpl
 
                            Coda File System
-                              Release 6
+                              Release 8
 
-          Copyright (c) 1987-2003 Carnegie Mellon University
+          Copyright (c) 1987-2021 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -17,7 +17,7 @@ listed in the file CREDITS.
 #*/
 
 #ifndef _VICE_VRDB_H_
-#define	_VICE_VRDB_H_	1
+#define _VICE_VRDB_H_ 1
 
 #ifdef __cplusplus
 extern "C" {
@@ -35,11 +35,13 @@ extern "C" {
 #include <inconsist.h>
 
 #include <vice_file.h>
+#include <deprecations.h>
 
-#define VRDB_PATH  vice_sharedfile("db/VRDB")
-#define VRDB_TEMP  vice_sharedfile("db/VRDB.new")
+#define VRDB_PATH vice_config_path("db/VRDB")
+#define VRDB_TEMP vice_config_path("db/VRDB.new")
+#define VRLIST_PATH vice_config_path("db/VRList")
 
-#define VRTABHASHSIZE	128
+#define VRTABHASHSIZE 128
 
 class vrtab_iterator;
 class vrent;
@@ -48,7 +50,8 @@ class vrtab : public ohashtab {
     friend void PrintVRDB();
     char *name;
     ohashtab namehtb;
-  public:
+
+public:
     vrtab(const char *name = "anonymous vrtab");
     ~vrtab();
     void add(vrent *);
@@ -64,26 +67,28 @@ class vrtab : public ohashtab {
     int dump(int);
 };
 
-
 /* each vrent is in 2 hash tables; lookup by replicated id and by volume name */
 class vrent : public olink {
-  public:   /* made public (temporarily?) to avoid multiple header include problems */
+public
+    : /* made public (temporarily?) to avoid multiple header include problems */
     char key[33];
     VolumeId volnum;
-    olink	namehtblink;
-    /*byte*/unsigned char nServers;
+    olink namehtblink;
+    /*byte*/ unsigned char nServers;
     VolumeId ServerVolnum[VSG_MEMBERS];
     uint32_t unused;
 
     vrent();
-    vrent(vrent&);
-    int operator=(vrent&);	    /* not supported! */
+    vrent(vrent &);
+    int operator=(vrent &); /* not supported! */
     ~vrent();
 
-//  public:
-    void GetHosts(unsigned long *);
-    int index(unsigned long);
-    void HostListToVV(unsigned long *, vv_t *);
+    //  public:
+    void GetHosts(unsigned long *) WARN_SINGLE_HOMING;
+    int index_by_hostaddr(unsigned long) WARN_SINGLE_HOMING;
+    int index_by_serverid(uint8_t serverid);
+    int index(void); /* get the replica index for this server */
+    void GetCheckVV(ViceVersionVector *);
     int GetVolumeInfo(VolumeInfo *);
     void hton();
     void ntoh();
@@ -97,8 +102,7 @@ class vrent : public olink {
 extern vrtab VRDB;
 extern void CheckVRDB();
 extern int DumpVRDB(int outfd);
-extern int XlateVid(VolumeId *, int * = NULL, int * = NULL);
+int XlateVid(VolumeId *, int * = NULL, int * = NULL, int *voltype = NULL);
 extern int ReverseXlateVid(VolumeId *, int * = NULL);
 
 #endif /* _VICE_VRDB_H_ */
-
