@@ -1,9 +1,9 @@
 /* BLURB lgpl
 
                            Coda File System
-                              Release 6
+                              Release 8
 
-          Copyright (c) 1987-2003 Carnegie Mellon University
+          Copyright (c) 1987-2025 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -22,26 +22,25 @@ Coda are listed in the file CREDITS.
 #include "coda_offsetof.h"
 
 /*
- * doubly linked list implementation -- based on linux 
+ * doubly linked list implementation -- based on linux
  * kernel code lists.
  *
  */
 
 struct dllist_head {
-	struct dllist_head *next, *prev;
+    struct dllist_head *next, *prev;
 };
 
-#define INIT_LIST_HEAD(name) \
-    struct dllist_head name = { &name, &name }
+#define INIT_LIST_HEAD(name) struct dllist_head name = { &name, &name }
 
 #define list_entry(ptr, type, member) \
-	((type *)((char *)(ptr)-offsetof(type, member)))
+    ((type *)((char *)(ptr) - offsetof(type, member)))
 
 #define list_entry_plusplus(ptr, type, member) \
-	((type *)((char *)(ptr)-coda_offsetof(type, member)))
+    ((type *)((char *)(ptr) - coda_offsetof(type, member)))
 
 #define list_for_each(ptr, head) \
-        for (ptr = (head).next; ptr != &(head); ptr = ptr->next)
+    for (ptr = (head).next; ptr != &(head); ptr = ptr->next)
 
 #ifdef __cplusplus
 extern "C" {
@@ -57,4 +56,3 @@ void list_head_init(struct dllist_head *ptr);
 #endif
 
 #endif /* _DLLIST_H_ */
-
